sarb_code: SARB code

View source: R/sarb_code.R

sarb_codeR Documentation

SARB code

Description

Request SARB data using the designated code with format KBPXXXX. This function is the worker function of the 'sarbR' package and is used to interact with an API linked to the main dataabse

Usage

sarb_code(code, token = NULL)

Arguments

code

SARB quaterly bulletin code

token

an API token generated by sarbR::token_request

Value

tibble

Examples

## Not run: 
sarb_code(code = "KBP6045J", token = "9eadf0a7a345a0cd286d81e74c555715")

Sys.setenv("sarb.token" = "9eadf0a7a345a0cd286d81e74c555715")
options(sarb.token = "9eadf0a7a345a0cd286d81e74c555715")

sarb_code(code = "KBP6045J")

## End(Not run)

HanjoStudy/sarbR documentation built on May 26, 2023, 3:44 p.m.