| sarb_code | R Documentation |
Request SARB data using the designated code with format KBPXXXX. This function is the worker function of the 'sarbR' package and is used to interact with an API linked to the main dataabse
sarb_code(code, token = NULL)
code |
SARB quaterly bulletin code |
token |
an API token generated by |
tibble
## Not run:
sarb_code(code = "KBP6045J", token = "9eadf0a7a345a0cd286d81e74c555715")
Sys.setenv("sarb.token" = "9eadf0a7a345a0cd286d81e74c555715")
options(sarb.token = "9eadf0a7a345a0cd286d81e74c555715")
sarb_code(code = "KBP6045J")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.